==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkParametricSuperEllipsoid.java <==
// java wrapper for vtkParametricSuperEllipsoid object
//

package vtk;
import vtk.*;

public class vtkParametricSuperEllipsoid extends vtkParametricFunction
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetDimension_2();
  public int GetDimension()
    { return GetDimension_2(); }

  private native void SetXRadius_3(double id0);
  public void SetXRadius(double id0)
    { SetXRadius_3(id0); }

  private native double GetXRadius_4();
  public double GetXRadius()
    { return GetXRadius_4(); }

  private native void SetYRadius_5(double id0);
  public void SetYRadius(double id0)
    { SetYRadius_5(id0); }

  private native double GetYRadius_6();
  public double GetYRadius()
    { return GetYRadius_6(); }

  private native void SetZRadius_7(double id0);
  public void SetZRadius(double id0)
    { SetZRadius_7(id0); }

  private native double GetZRadius_8();
  public double GetZRadius()
    { return GetZRadius_8(); }

  private native void SetN1_9(double id0);
  public void SetN1(double id0)
    { SetN1_9(id0); }

  private native double GetN1_10();
  public double GetN1()
    { return GetN1_10(); }

  private native void SetN2_11(double id0);
  public void SetN2(double id0)
    { SetN2_11(id0); }

  private native double GetN2_12();
  public double GetN2()
    { return GetN2_12(); }

  private native void Evaluate_13(double id0[],double id1[],double id2[]);
  public void Evaluate(double id0[],double id1[],double id2[])
    { Evaluate_13(id0,id1,id2); }

  private native double EvaluateScalar_14(double id0[],double id1[],double id2[]);
  public double EvaluateScalar(double id0[],double id1[],double id2[])
    { return EvaluateScalar_14(id0,id1,id2); }

  public vtkParametricSuperEllipsoid() { super(); }

  public vtkParametricSuperEllipsoid(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-17-aarch64.pkg.tar.xz: vtk/vtkParametricSuperEllipsoid.java <==
// java wrapper for vtkParametricSuperEllipsoid object
//

package vtk;
import vtk.*;

public class vtkParametricSuperEllipsoid extends vtkParametricFunction
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native int GetDimension_2();
  public int GetDimension()
    { return GetDimension_2(); }

  private native void SetXRadius_3(double id0);
  public void SetXRadius(double id0)
    { SetXRadius_3(id0); }

  private native double GetXRadius_4();
  public double GetXRadius()
    { return GetXRadius_4(); }

  private native void SetYRadius_5(double id0);
  public void SetYRadius(double id0)
    { SetYRadius_5(id0); }

  private native double GetYRadius_6();
  public double GetYRadius()
    { return GetYRadius_6(); }

  private native void SetZRadius_7(double id0);
  public void SetZRadius(double id0)
    { SetZRadius_7(id0); }

  private native double GetZRadius_8();
  public double GetZRadius()
    { return GetZRadius_8(); }

  private native void SetN1_9(double id0);
  public void SetN1(double id0)
    { SetN1_9(id0); }

  private native double GetN1_10();
  public double GetN1()
    { return GetN1_10(); }

  private native void SetN2_11(double id0);
  public void SetN2(double id0)
    { SetN2_11(id0); }

  private native double GetN2_12();
  public double GetN2()
    { return GetN2_12(); }

  private native void Evaluate_13(double id0[],double id1[],double id2[]);
  public void Evaluate(double id0[],double id1[],double id2[])
    { Evaluate_13(id0,id1,id2); }

  private native double EvaluateScalar_14(double id0[],double id1[],double id2[]);
  public double EvaluateScalar(double id0[],double id1[],double id2[])
    { return EvaluateScalar_14(id0,id1,id2); }

  public vtkParametricSuperEllipsoid() { super(); }

  public vtkParametricSuperEllipsoid(long id) { super(id); }
  public native long   VTKInit();

}
